@@ -7,7 +7,7 @@ no warnings;
 use subs qw();
 use vars qw($VERSION);
 
-$VERSION = '1.044';
+$VERSION = '1.046';
 
 =encoding utf8
 
@@ -117,8 +117,8 @@ sub init {
 
 =item get_modules( FILE )
 
-Returns a list of namespaces explicity use-d in FILE. Returns undef if
-the file does not exist or if it can't parse the file.
+Returns a list of namespaces explicity use-d in FILE. Returns the
+empty list if the file does not exist or if it can't parse the file.
 
 Each used namespace is only in the list even if it is used multiple
 times in the file. The order of the list does not correspond to
@@ -132,7 +132,6 @@ sub get_modules {
 	$self->_clear_error;
 
 	my $details = $self->get_modules_with_details( $file );
-	return unless defined $details;
 
 	my @modules = map { $_->module } @$details;
 
@@ -210,8 +209,7 @@ sub _regular_load {
 
 	my $modules = $Document->find(
 		sub {
-			$_[1]->isa( 'PPI::Statement::Include' )  &&
-				( $_[1]->type eq 'use' || $_[1]->type eq 'require' )
+			$_[1]->isa( 'PPI::Statement::Include' )
 			}
 		);
 
@@ -242,7 +240,7 @@ sub _isa_load {
 			map {
 				bless {
 					content => $m->content,
-					pragma  => undef,
+					pragma  => '',
 					direct  => 0,
 					module  => $_,
 					imports => [],
